@@ -3,11 +3,16 @@ import pdb
 # from gi.repository import Notify
 from subprocess import call
 
-
 monitored_channels = {} # "channel_name": time_i_last_chatted
-def generate_actions_from_irc_message(args):
-    global monitored_channels
 
+def generate_actions_from_irc_message(args):
+    # Generate a list of action based on input args.  The design of this
+    # code is to run the generate_actions_from_irc_message method with a
+    # give set of inputs: from_who, channel, message, and to_me?.  Based on
+    # these inputs some actions will be generated...like send me a
+    # notification if the message is on a channel I'm monitoring, or play a
+    # sound if a message is directly to me.
+    global monitored_channels
     from_who = args[u"from_who"]
     channel = args[u"channel"]
     message = args[u"message"]
@@ -40,6 +45,45 @@ def generate_actions_from_irc_message(args):
                                            u"urgency": u"low"}} )
     return actions_todo
 
+
+# This method dispatches to the required action.  Each action takes a
+# hash/dict as an argument, this contains the actual arguments.
+def perform_actions(action_list):
+    for action in action_list:
+        function = action[u"action"]
+        arguments = action[u"arguments"]
+        function(arguments)
+
+#######################
+# THE ACTIONS
+
+def display_alert(args):
+    alert_title = args[u'alert_title']
+    alert_message = args[u'alert_message']
+    urgency = args[u'urgency']
+    # msg=Notify.Notification.new (alert_title, alert_message, u"dialog-information")
+    # msg.show ()
+    cmd = construct_notification_command(alert_title, alert_message, urgency)
+#    pdb.set_trace()
+    call(cmd)    
+
+def monitored_channel(channel, monitored_channels):
+    for mon_channel, last_chatted in monitored_channels.items():
+        if channel == mon_channel:
+            elapsed_time_since_i_chatted = time.time() - last_chatted
+            if elapsed_time_since_i_chatted < seconds_listen_channel:
+                return True
+    return False
+
+    
+def play_sound(args):
+    filename = u"~/bin/sounds/" + args[u'sound_file'] + u".ogg"    
+    call([u"play", u"-q", filename])    
+
+
+##########################
+## HELPERS
+
 def construct_alert(frm, channel, msg, elapsed=None):
     alert_title = frm + u"@" + channel + u":"
     message = msg
@@ -60,24 +104,6 @@ def remove_expired_channels( monitored_channels ):
     for channel in expired_channels:
         monitored_channels.pop(channel, time.time())
 
-def monitored_channel(channel, monitored_channels):
-    for mon_channel, last_chatted in monitored_channels.items():
-        if channel == mon_channel:
-            elapsed_time_since_i_chatted = time.time() - last_chatted
-            if elapsed_time_since_i_chatted < seconds_listen_channel:
-                return True
-    return False
-
-def perform_actions(action_list):
-    for action in action_list:
-        function = action[u"action"]
-        arguments = action[u"arguments"]
-        function(arguments)
-    
-def play_sound(args):
-    filename = u"~/bin/sounds/" + args[u'sound_file'] + u".ogg"    
-    call([u"play", u"-q", filename])    
-
 def i_wrote_message(who):
     # search for string 'fenton' in who string
     if who == my_username or who[1:] == my_username:
@@ -85,15 +111,7 @@ def i_wrote_message(who):
     else:
         return False
 
-def display_alert(args):
-    alert_title = args[u'alert_title']
-    alert_message = args[u'alert_message']
-    urgency = args[u'urgency']
-    # msg=Notify.Notification.new (alert_title, alert_message, u"dialog-information")
-    # msg.show ()
-    cmd = construct_notification_command(alert_title, alert_message, urgency)
-#    pdb.set_trace()
-    call(cmd)    
+
 
 def construct_notification_command( title, body, urgency ):
     # notify-send -h string:bgcolor:#ff0000 -h string:fgcolor:#ff444 'Hello world!' 'This is an example notification.' --icon=dialog-information
@@ -138,7 +156,7 @@ def display_state():
     print("MONITORING CHANNELS:")
     for channel, monitored_since in monitored_channels.items():
         elapsed = time.time() - monitored_since
-        print ( "\t" + channel + ", for: " + str(round(elapsed)) + " of " + str(imp.seconds_listen_channel) + "(s)" )
+        print ( "\t" + channel + ", for: " + str(round(elapsed)) + " of " + str(seconds_listen_channel) + "(s)" )
 
 def printall(incoming_message, response_actions, start_time):
     display_incoming_message(incoming_message, start_time)
